Why do I have to sign up? → Data lineage needs a user identity to answer questions like: Who modified which data when? Who shares this with me?

Signing up takes 1 min. On the command line, run:

- `lamin signup <email>`
- `lamin login <handle>`

```{note}

Lamin does _not_ store or see any of your data, but only _basic_ metadata about you (email address, etc.) & your LaminDB instances (S3 bucket names, etc.): see the [open-source client](https://github.com/laminlabs/lamindb-setup).

```
